*********************
The sherpa.fit module
*********************

.. currentmodule:: sherpa.fit

.. automodule:: sherpa.fit

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      Fit
      IterFit
      FitResults
      StatInfoResults
      ErrorEstResults

Class Inheritance Diagram
=========================

.. inheritance-diagram::  Fit IterFit FitResults StatInfoResults ErrorEstResults
   :parts: 1
             

